@@ -125,7 +125,6 @@ impl BigTableConnection {
         instance_name: &str,
         read_only: bool,
         timeout: Option<Duration>,
-        credential_path: Option<String>,
     ) -> Result<Self> {
         match std::env::var("BIGTABLE_EMULATOR_HOST") {
             Ok(endpoint) => {
@@ -135,21 +134,18 @@ impl BigTableConnection {
                     access_token: None,
                     channel: tonic::transport::Channel::from_shared(format!("http://{}", endpoint))
                         .map_err(|err| Error::InvalidUri(endpoint, err.to_string()))?
-                        .connect_lazy()?,
+                        .connect_lazy(),
                     table_prefix: format!("projects/emulator/instances/{}/tables/", instance_name),
                     timeout,
                 })
             }
 
             Err(_) => {
-                let access_token = AccessToken::new(
-                    if read_only {
-                        Scope::BigTableDataReadOnly
-                    } else {
-                        Scope::BigTableData
-                    },
-                    credential_path,
-                )
+                let access_token = AccessToken::new(if read_only {
+                    Scope::BigTableDataReadOnly
+                } else {
+                    Scope::BigTableData
+                })
                 .await
                 .map_err(Error::AccessToken)?;
 
@@ -179,7 +175,7 @@ impl BigTableConnection {
 
                 Ok(Self {
                     access_token: Some(access_token),
-                    channel: endpoint.connect_lazy()?,
+                    channel: endpoint.connect_lazy(),
                     table_prefix,
                     timeout,
                 })
